@@ -3,10 +3,7 @@
 from django.test import TestCase as DjangoTestCase
 from django.utils import unittest
 
-from jsonfield.tests.jsonfield_test_app.models import (
-    JSONFieldTestModel,
-    JSONFieldWithDefaultTestModel,
-)
+from jsonfield.tests.jsonfield_test_app.models import *
 from jsonfield import JSONField
 
 class JSONFieldTest(DjangoTestCase):
@@ -38,8 +35,8 @@ class JSONFieldTest(DjangoTestCase):
     def test_db_prep_save(self):
         field = JSONField(u"test")
         field.set_attributes_from_name("json")
-        self.assertEquals(None, field.get_db_prep_save(None, None))
-        self.assertEquals('{"spam": "eggs"}', field.get_db_prep_save({"spam": "eggs"}, None))
+        self.assertEquals(None, field.get_db_prep_save(None, connection=None))
+        self.assertEquals('{"spam": "eggs"}', field.get_db_prep_save({"spam": "eggs"}, connection=None))
 
     @unittest.expectedFailure
     def test_value_to_string(self):
@@ -85,4 +82,15 @@ class JSONFieldTest(DjangoTestCase):
         JSONFieldTestModel.objects.create(json={'foo':'bar'})
         
         self.assertEquals(1, JSONFieldTestModel.objects.filter(json=None).count())
-        self.assertEquals(None, JSONFieldTestModel.objects.get(json=None).json)
\ No newline at end of file
+        self.assertEquals(None, JSONFieldTestModel.objects.get(json=None).json)
+    
+    def test_jsonfield_blank(self):
+        BlankJSONFieldTestModel.objects.create(blank_json='', null_json=None)
+        obj = BlankJSONFieldTestModel.objects.get()
+        self.assertEquals(None, obj.null_json)
+        self.assertEquals("", obj.blank_json)
+        obj.save()
+        obj = BlankJSONFieldTestModel.objects.get()
+        self.assertEquals(None, obj.null_json)
+        self.assertEquals("", obj.blank_json)
+        
\ No newline at end of file
